==> mbegroup-job-v1.2.1-011032.zip: src/Providers/JobServiceProvider.php <==
<?php
namespace MbeGroup\Job\Providers;

use Illuminate\Support\ServiceProvider;
use MbeGroup\Job\Services;
use MbeGroup\Job\Contracts;
use MbeGroup\Job\Console\Commands;

final class JobServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        $this->app->bind(
            Contracts\JobOfferContentServiceInterface::class,
            Services\JobOfferContentService::class
        );
        $this->app->bind(
            Contracts\JobOffersSearchServiceInterface::class,
            Services\JobOffersSearchService::class
        );
        $this->app->bind(
            Contracts\JobOffersSalaryServiceInterface::class,
            Services\JobOffersSalaryService::class
        );

        $this->app->bind(
            Contracts\JobOfferArchiveServiceInterface::class,
            Services\JobOfferArchiveService::class
        );

        $this->app->bind(
            Contracts\ScraperJobOfferServiceInterface::class,
            Services\ScraperJobOfferService::class
        );

        $this->app->bind(
            Contracts\JobOfferCopyServiceInterface::class,
            Services\JobOfferCopyService::class
        );

        $this->app->bind(
            Contracts\ConnectJobOffersServiceInterface::class,
            Services\ConnectJobOffersService::class
        );
    }

    public function boot(): void
    {
        $this->loadRoutesFrom(__DIR__ . '/../../routes/api.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/console.php');
        $this->loadTranslationsFrom(__DIR__ . '/../../lang', 'job');
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'job');
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\JobOffersReindex::class,
                Commands\JobOffersExpire::class,
                Commands\JobOffersArchive::class,
                Commands\CheckImportsCommand::class,
                Commands\RunImportCommand::class,
            ]);
        }
    }
}

==> mbegroup-job-v1.2.4-840403.zip: src/Providers/JobServiceProvider.php <==
<?php
namespace MbeGroup\Job\Providers;

use Illuminate\Support\ServiceProvider;
use MbeGroup\Job\Services;
use MbeGroup\Job\Contracts;
use MbeGroup\Job\Console\Commands;

final class JobServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        $this->app->bind(
            Contracts\JobOfferContentServiceInterface::class,
            Services\JobOfferContentService::class
        );
        $this->app->bind(
            Contracts\JobOffersSearchServiceInterface::class,
            Services\JobOffersSearchService::class
        );
        $this->app->bind(
            Contracts\JobOffersSalaryServiceInterface::class,
            Services\JobOffersSalaryService::class
        );

        $this->app->bind(
            Contracts\JobOfferArchiveServiceInterface::class,
            Services\JobOfferArchiveService::class
        );

        $this->app->bind(
            Contracts\ScraperJobOfferServiceInterface::class,
            Services\ScraperJobOfferService::class
        );

        $this->app->bind(
            Contracts\JobOfferCopyServiceInterface::class,
            Services\JobOfferCopyService::class
        );

        $this->app->bind(
            Contracts\ConnectJobOffersServiceInterface::class,
            Services\ConnectJobOffersService::class
        );

        $this->app->bind(
            Contracts\ApplicationServiceInterface::class,
            Services\ApplicationService::class
        );

        $this->app->bind(
            Contracts\FavoriteServiceInterface::class,
            Services\FavoriteService::class
        );
    }

    public function boot(): void
    {
        $this->loadRoutesFrom(__DIR__ . '/../../routes/api.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/console.php');
        $this->loadTranslationsFrom(__DIR__ . '/../../lang', 'job');
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'job');
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\JobOffersReindex::class,
                Commands\JobOffersExpire::class,
                Commands\JobOffersArchive::class,
                Commands\CheckImportsCommand::class,
                Commands\RunImportCommand::class,
            ]);
        }
    }
}
